@@ -12,11 +12,13 @@ import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_ecr._jsii
 import aws_cdk.aws_ecs._jsii
 import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_secretsmanager._jsii
+import aws_cdk.aws_ssm._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-batch", "1.74.0", __name__[0:-6], "aws-batch@1.74.0.jsii.tgz"
+    "@aws-cdk/aws-batch", "1.78.0", __name__[0:-6], "aws-batch@1.78.0.jsii.tgz"
 )
 
 __all__ = [
